@@ -26,9 +26,9 @@ class MystBuilder(AbstractClass):
     def setenv(self,key,value):
         self.env_vars[key] = value
 
-    def build(self,*args):
+    def build(self,*args,user=None,group=None):
         if self.hub is not None:
             self.cprint(f'Starting MyST build {self.hub.jh_url}','yellow')
         else:
             self.cprint(f'Starting MyST build no exec.','yellow')
-        self.myst_client.build('build',*args)
\ No newline at end of file
+        self.myst_client.build('build',*args,user=user,group=group)
\ No newline at end of file
